CliError

Enum CliError 

pub enum CliError {
Show 34 variants UnknownCommand, UnknownCommandName { command: String, next: &'static str, }, MissingArgument { argument: &'static str, next: &'static str, }, MissingFlagValue { flag: &'static str, next: &'static str, }, DuplicateFlag { flag: &'static str, next: &'static str, }, UnexpectedArgument { argument: String, command: &'static str, next: &'static str, }, UnknownFlag { flag: String, next: &'static str, }, UnsupportedFlag { flag: String, command: &'static str, next: &'static str, }, UnknownResource { resource: String, next: &'static str, }, UnknownStatus(String), UnknownTraceStatus(String), UnknownLogLevel(String), InvalidLimit(String), InvalidMinDuration(String), UnknownPagination, InvalidActionCursor(String), InvalidLogCursor(String), InvalidIssueCursor(String), InvalidSupportCursor(String), UnknownSupportCategory, InvalidSupportTicketId, InvalidSupportRetryKey, InvalidSupportContextReply, InvalidSupportContextCommand, InvalidSupportContext, InvalidInvestigationCommand, InvalidDoctorCommand, InvalidProjectCreateCommand, InvalidProjectsCommand, InvalidLoginProvider, InvalidUsageCommand, InvalidNativeDebugCommand, InvalidNativeDebugIdentity, InvalidSetupSource(String),
}
CLI parsing error.

Variants



UnknownCommand

Command is missing or unsupported.



UnknownCommandName

Command name is unsupported.

Fields

command: String

Unsupported command name.

next: &'static str

Suggested next step.



MissingArgument

Required command argument is missing.

Fields

argument: &'static str

Missing argument name.

next: &'static str

Argument-specific next step.



MissingFlagValue

Required flag value is missing.

Fields

flag: &'static str

Flag missing a value.

next: &'static str

Flag-specific next step.



DuplicateFlag

Flag is present more than once.

Fields

flag: &'static str

Duplicate flag value.

next: &'static str

Flag-specific next step.



UnexpectedArgument

Positional argument is unsupported for the selected command.

Fields

argument: String

Unexpected argument value.

command: &'static str

Command name.

next: &'static str

Command-specific next step.



UnknownFlag

Flag is unknown for the selected command.

Fields

flag: String

Unknown flag value.

next: &'static str

Command-specific next step.



UnsupportedFlag

Flag is known globally but unsupported for the selected command.

Fields

flag: String

Unsupported flag value.

command: &'static str

Command name.

next: &'static str

Command-specific next step.



UnknownResource

Resource is unsupported for the selected command.

Fields

resource: String

Unsupported resource value.

next: &'static str

Command-specific next step.



UnknownStatus(String)

Issue status is unsupported.



UnknownTraceStatus(String)

Trace status is unsupported.



UnknownLogLevel(String)

Log level is unsupported.



InvalidLimit(String)

Row limit is malformed.



InvalidMinDuration(String)

Minimum trace duration is malformed.



UnknownPagination

Pagination mode is unsupported.



InvalidActionCursor(String)

Action cursor fields are inconsistent.



InvalidLogCursor(String)

Log cursor fields are inconsistent.



InvalidIssueCursor(String)

Issue cursor fields are inconsistent.



InvalidSupportCursor(String)

Support-ticket cursor fields are inconsistent.



UnknownSupportCategory

Support-ticket category is unsupported.



InvalidSupportTicketId

Support-ticket identifier is not in the public sup_ form.



InvalidSupportRetryKey

Support context retry key cannot be sent as an HTTP header value.



InvalidSupportContextReply

Support context reply syntax is malformed.



InvalidSupportContextCommand

Support context history syntax is malformed.



InvalidSupportContext

Support context text is blank or exceeds the public limit.



InvalidInvestigationCommand

Issue investigation syntax is malformed.



InvalidDoctorCommand

Project-scoped doctor syntax is malformed.



InvalidProjectCreateCommand

Secure project creation syntax is malformed.



InvalidProjectsCommand

Authenticated project catalog syntax is malformed.



InvalidLoginProvider

Native browser login provider is unsupported.



InvalidUsageCommand

Account usage read syntax is malformed.



InvalidNativeDebugCommand

Native debug-artifact command syntax is malformed.



InvalidNativeDebugIdentity

Native debug-artifact identity is not canonical.



InvalidSetupSource(String)

Project setup source is malformed.